# Bespoke Curator

Bespoke Labs Synthetic Data Curation Library

### Installation

```bash
poetry install
```

### Usage

To run the camel example:

```bash
poetry run python examples/camel.py
poetry run python examples/openhermesv3.py
```

Run the tests:

```bash
poetry run pytest
```

## Bespoke Dataset Viewer

To run the bespoke dataset viewer:

```bash
npm run dev
```

In case `next` is not installed, you can install it with:

```bash
npm install next@latest
```
